# Class: Driver&#95;variant

UNSUPPORTED. Variant of a host driver

## Fields for class: Driver&#95;variant

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`driver`            |`Host_driver ref`   |_RO/runtime_   |Driver this variant is a part of        |
|`hardware_present`  |`bool`              |_RO/runtime_   |True if the hardware for this variant is present on the host|
|`name`              |`string`            |_RO/runtime_   |Name identifying the driver variant within the driver|
|`priority`          |`float`             |_RO/runtime_   |Priority; this needs an explanation how this is ordered|
|`status`            |`string`            |_RO/runtime_   |Development and release status of this variant, like 'alpha'|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`version`           |`string`            |_RO/runtime_   |Unique version of this driver variant   |

## RPCs associated with class: Driver&#95;variant

### RPC name: get&#95;all

_Overview:_

Return a list of all the Driver&#95;variants known to the system.

_Signature:_

```
Driver_variant ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Driver_variant ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Driver&#95;variant references to Driver&#95;variant records for all Driver&#95;variants known to the system.

_Signature:_

```
(Driver_variant ref -> Driver_variant record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Driver_variant ref -> Driver_variant record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Driver&#95;variant instance with the specified UUID.

_Signature:_

```
Driver_variant ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Driver_variant ref`

reference to the object

### RPC name: get&#95;driver

_Overview:_

Get the driver field of the given Driver&#95;variant.

_Signature:_

```
Host_driver ref get_driver (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Host_driver ref`

value of the field

### RPC name: get&#95;hardware&#95;present

_Overview:_

Get the hardware&#95;present field of the given Driver&#95;variant.

_Signature:_

```
bool get_hardware_present (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;name

_Overview:_

Get the name field of the given Driver&#95;variant.

_Signature:_

```
string get_name (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;priority

_Overview:_

Get the priority field of the given Driver&#95;variant.

_Signature:_

```
float get_priority (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Driver&#95;variant.

_Signature:_

```
Driver_variant record get_record (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Driver_variant record`

all fields from the object

### RPC name: get&#95;status

_Overview:_

Get the status field of the given Driver&#95;variant.

_Signature:_

```
string get_status (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Driver&#95;variant.

_Signature:_

```
string get_uuid (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;version

_Overview:_

Get the version field of the given Driver&#95;variant.

_Signature:_

```
string get_version (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: select

_Overview:_

UNSUPPORTED Select this variant of a driver to become active after reboot or immediately if currently no version is active

_Signature:_

```
void select (session ref session_ref, Driver_variant ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Driver_variant ref`          |`self`                        |Driver variant to become active &#40;after reboot&#41;.|

_Minimum Role:_ pool-admin

_Return Type:_ `void`
